# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/generated/inner/v1/app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/generated/inner/v1/app.proto',
  package='grebbleFlow.inner.v1',
  syntax='proto3',
  serialized_options=b'Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.grebble_flow/grpc/generated/inner/v1/app.proto\x12\x14grebbleFlow.inner.v1\"\x18\n\x16\x41ppExternalInfoRequest\"8\n\x13\x41ttributeSchemaItem\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xab\x01\n\x0f\x41ttributeSchema\x12?\n\x05items\x18\x01 \x03(\x0b\x32\x30.grebbleFlow.inner.v1.AttributeSchema.ItemsEntry\x1aW\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).grebbleFlow.inner.v1.AttributeSchemaItem:\x02\x38\x01\"e\n\x15ProcessorExternalInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x0f\x61ttributeSchema\x18\x02 \x01(\x0b\x32%.grebbleFlow.inner.v1.AttributeSchema\"Z\n\x17\x41ppInfoExternalResponse\x12?\n\nprocessors\x18\x01 \x03(\x0b\x32+.grebbleFlow.inner.v1.ProcessorExternalInfo2w\n\x0b\x45xternalApp\x12h\n\x07\x41ppInfo\x12,.grebbleFlow.inner.v1.AppExternalInfoRequest\x1a-.grebbleFlow.inner.v1.AppInfoExternalResponse\"\x00\x42:Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1b\x06proto3'
)




_APPEXTERNALINFOREQUEST = _descriptor.Descriptor(
  name='AppExternalInfoRequest',
  full_name='grebbleFlow.inner.v1.AppExternalInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=96,
)


_ATTRIBUTESCHEMAITEM = _descriptor.Descriptor(
  name='AttributeSchemaItem',
  full_name='grebbleFlow.inner.v1.AttributeSchemaItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='grebbleFlow.inner.v1.AttributeSchemaItem.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='grebbleFlow.inner.v1.AttributeSchemaItem.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=154,
)


_ATTRIBUTESCHEMA_ITEMSENTRY = _descriptor.Descriptor(
  name='ItemsEntry',
  full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.AttributeSchema.ItemsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=328,
)

_ATTRIBUTESCHEMA = _descriptor.Descriptor(
  name='AttributeSchema',
  full_name='grebbleFlow.inner.v1.AttributeSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='grebbleFlow.inner.v1.AttributeSchema.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTESCHEMA_ITEMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=328,
)


_PROCESSOREXTERNALINFO = _descriptor.Descriptor(
  name='ProcessorExternalInfo',
  full_name='grebbleFlow.inner.v1.ProcessorExternalInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grebbleFlow.inner.v1.ProcessorExternalInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeSchema', full_name='grebbleFlow.inner.v1.ProcessorExternalInfo.attributeSchema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=431,
)


_APPINFOEXTERNALRESPONSE = _descriptor.Descriptor(
  name='AppInfoExternalResponse',
  full_name='grebbleFlow.inner.v1.AppInfoExternalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='grebbleFlow.inner.v1.AppInfoExternalResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=523,
)

_ATTRIBUTESCHEMA_ITEMSENTRY.fields_by_name['value'].message_type = _ATTRIBUTESCHEMAITEM
_ATTRIBUTESCHEMA_ITEMSENTRY.containing_type = _ATTRIBUTESCHEMA
_ATTRIBUTESCHEMA.fields_by_name['items'].message_type = _ATTRIBUTESCHEMA_ITEMSENTRY
_PROCESSOREXTERNALINFO.fields_by_name['attributeSchema'].message_type = _ATTRIBUTESCHEMA
_APPINFOEXTERNALRESPONSE.fields_by_name['processors'].message_type = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppExternalInfoRequest'] = _APPEXTERNALINFOREQUEST
DESCRIPTOR.message_types_by_name['AttributeSchemaItem'] = _ATTRIBUTESCHEMAITEM
DESCRIPTOR.message_types_by_name['AttributeSchema'] = _ATTRIBUTESCHEMA
DESCRIPTOR.message_types_by_name['ProcessorExternalInfo'] = _PROCESSOREXTERNALINFO
DESCRIPTOR.message_types_by_name['AppInfoExternalResponse'] = _APPINFOEXTERNALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppExternalInfoRequest = _reflection.GeneratedProtocolMessageType('AppExternalInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPEXTERNALINFOREQUEST,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AppExternalInfoRequest)
  })
_sym_db.RegisterMessage(AppExternalInfoRequest)

AttributeSchemaItem = _reflection.GeneratedProtocolMessageType('AttributeSchemaItem', (_message.Message,), {
  'DESCRIPTOR' : _ATTRIBUTESCHEMAITEM,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchemaItem)
  })
_sym_db.RegisterMessage(AttributeSchemaItem)

AttributeSchema = _reflection.GeneratedProtocolMessageType('AttributeSchema', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ATTRIBUTESCHEMA_ITEMSENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchema.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _ATTRIBUTESCHEMA,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AttributeSchema)
  })
_sym_db.RegisterMessage(AttributeSchema)
_sym_db.RegisterMessage(AttributeSchema.ItemsEntry)

ProcessorExternalInfo = _reflection.GeneratedProtocolMessageType('ProcessorExternalInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSOREXTERNALINFO,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.ProcessorExternalInfo)
  })
_sym_db.RegisterMessage(ProcessorExternalInfo)

AppInfoExternalResponse = _reflection.GeneratedProtocolMessageType('AppInfoExternalResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPINFOEXTERNALRESPONSE,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.app_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.AppInfoExternalResponse)
  })
_sym_db.RegisterMessage(AppInfoExternalResponse)


DESCRIPTOR._options = None
_ATTRIBUTESCHEMA_ITEMSENTRY._options = None

_EXTERNALAPP = _descriptor.ServiceDescriptor(
  name='ExternalApp',
  full_name='grebbleFlow.inner.v1.ExternalApp',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=525,
  serialized_end=644,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppInfo',
    full_name='grebbleFlow.inner.v1.ExternalApp.AppInfo',
    index=0,
    containing_service=None,
    input_type=_APPEXTERNALINFOREQUEST,
    output_type=_APPINFOEXTERNALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALAPP)

DESCRIPTOR.services_by_name['ExternalApp'] = _EXTERNALAPP

# @@protoc_insertion_point(module_scope)
