# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/generated/inner/v1/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/generated/inner/v1/processor.proto',
  package='grebbleFlow.inner.v1',
  syntax='proto3',
  serialized_options=b'Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4grebble_flow/grpc/generated/inner/v1/processor.proto\x12\x14grebbleFlow.inner.v1\"\xb8\x01\n\x12\x46lowExecuteRequest\x12\x10\n\x08\x66lowName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12L\n\nattributes\x18\x03 \x03(\x0b\x32\x38.grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x01\n\x13\x46lowExecuteResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12M\n\nattributes\x18\x02 \x03(\x0b\x32\x39.grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry\x12\x10\n\x08mimeType\x18\x03 \x01(\t\x12\x11\n\tstreamEnd\x18\x04 \x01(\x08\x12\x0e\n\x06\x63ommit\x18\x05 \x01(\x08\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32o\n\tProcessor\x12\x62\n\x07\x45xecute\x12(.grebbleFlow.inner.v1.FlowExecuteRequest\x1a).grebbleFlow.inner.v1.FlowExecuteResponse\"\x00\x30\x01\x42:Z8gitlab.com/grebble/backend/go-mono/pkg/grpc/generated/v1b\x06proto3'
)




_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=263,
)

_FLOWEXECUTEREQUEST = _descriptor.Descriptor(
  name='FlowExecuteRequest',
  full_name='grebbleFlow.inner.v1.FlowExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowName', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.flowName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.inner.v1.FlowExecuteRequest.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=263,
)


_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=263,
)

_FLOWEXECUTERESPONSE = _descriptor.Descriptor(
  name='FlowExecuteResponse',
  full_name='grebbleFlow.inner.v1.FlowExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mimeType', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.mimeType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamEnd', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.streamEnd', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit', full_name='grebbleFlow.inner.v1.FlowExecuteResponse.commit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=487,
)

_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY.containing_type = _FLOWEXECUTEREQUEST
_FLOWEXECUTEREQUEST.fields_by_name['attributes'].message_type = _FLOWEXECUTEREQUEST_ATTRIBUTESENTRY
_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY.containing_type = _FLOWEXECUTERESPONSE
_FLOWEXECUTERESPONSE.fields_by_name['attributes'].message_type = _FLOWEXECUTERESPONSE_ATTRIBUTESENTRY
DESCRIPTOR.message_types_by_name['FlowExecuteRequest'] = _FLOWEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['FlowExecuteResponse'] = _FLOWEXECUTERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowExecuteRequest = _reflection.GeneratedProtocolMessageType('FlowExecuteRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWEXECUTEREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _FLOWEXECUTEREQUEST,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteRequest)
  })
_sym_db.RegisterMessage(FlowExecuteRequest)
_sym_db.RegisterMessage(FlowExecuteRequest.AttributesEntry)

FlowExecuteResponse = _reflection.GeneratedProtocolMessageType('FlowExecuteResponse', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLOWEXECUTERESPONSE_ATTRIBUTESENTRY,
    '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
    # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteResponse.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _FLOWEXECUTERESPONSE,
  '__module__' : 'grebble_flow.grpc.generated.inner.v1.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebbleFlow.inner.v1.FlowExecuteResponse)
  })
_sym_db.RegisterMessage(FlowExecuteResponse)
_sym_db.RegisterMessage(FlowExecuteResponse.AttributesEntry)


DESCRIPTOR._options = None
_FLOWEXECUTEREQUEST_ATTRIBUTESENTRY._options = None
_FLOWEXECUTERESPONSE_ATTRIBUTESENTRY._options = None

_PROCESSOR = _descriptor.ServiceDescriptor(
  name='Processor',
  full_name='grebbleFlow.inner.v1.Processor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=489,
  serialized_end=600,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='grebbleFlow.inner.v1.Processor.Execute',
    index=0,
    containing_service=None,
    input_type=_FLOWEXECUTEREQUEST,
    output_type=_FLOWEXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSOR)

DESCRIPTOR.services_by_name['Processor'] = _PROCESSOR

# @@protoc_insertion_point(module_scope)
